no_std compatible implementation of the unsigned-varint Format
Features
| Feature | Description |
|---|---|
std | Allows Error to be converted to std::io::Error |
Enums
- Error
- Errors that can occur decoding an unsigned varint.
Functions
- decode
- Decodes an unsigned integer from a given buffer, returning the integer and the amount of bytes read.
- encode
- Encode a unsigned integer into an unsigned varint and write it into the buffer. Returns the number of bytes written.
- encoded_
len - Get the number of bytes needed to encode
num